==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/EntityRiskPolicyRuleAllOfActions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EntityRiskPolicyRuleAllOfActionsEntityRisk;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The action to take based on the risk event
 */
@ApiModel(description = "The action to take based on the risk event")
@JsonPropertyOrder({ EntityRiskPolicyRuleAllOfActions.JSON_PROPERTY_ENTITY_RISK })
@JsonTypeName("EntityRiskPolicyRule_allOf_actions")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class EntityRiskPolicyRuleAllOfActions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ENTITY_RISK = "entityRisk";
    private EntityRiskPolicyRuleAllOfActionsEntityRisk entityRisk;

    public EntityRiskPolicyRuleAllOfActions() {
    }

    public EntityRiskPolicyRuleAllOfActions entityRisk(EntityRiskPolicyRuleAllOfActionsEntityRisk entityRisk) {

        this.entityRisk = entityRisk;
        return this;
    }

    /**
     * Get entityRisk
     *
     * @return entityRisk
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENTITY_RISK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EntityRiskPolicyRuleAllOfActionsEntityRisk getEntityRisk() {
        return entityRisk;
    }

    @JsonProperty(JSON_PROPERTY_ENTITY_RISK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEntityRisk(EntityRiskPolicyRuleAllOfActionsEntityRisk entityRisk) {
        this.entityRisk = entityRisk;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EntityRiskPolicyRuleAllOfActions entityRiskPolicyRuleAllOfActions = (EntityRiskPolicyRuleAllOfActions) o;
        return Objects.equals(this.entityRisk, entityRiskPolicyRuleAllOfActions.entityRisk);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(entityRisk);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EntityRiskPolicyRuleAllOfActions {\n");
        sb.append("    entityRisk: ").append(toIndentedString(entityRisk)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/EntityRiskPolicyRuleAllOfActions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EntityRiskPolicyRuleAllOfActionsEntityRisk;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The action to take based on the risk event
 */
@ApiModel(description = "The action to take based on the risk event")
@JsonPropertyOrder({ EntityRiskPolicyRuleAllOfActions.JSON_PROPERTY_ENTITY_RISK })
@JsonTypeName("EntityRiskPolicyRule_allOf_actions")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class EntityRiskPolicyRuleAllOfActions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ENTITY_RISK = "entityRisk";
    private EntityRiskPolicyRuleAllOfActionsEntityRisk entityRisk;

    public EntityRiskPolicyRuleAllOfActions() {
    }

    public EntityRiskPolicyRuleAllOfActions entityRisk(EntityRiskPolicyRuleAllOfActionsEntityRisk entityRisk) {

        this.entityRisk = entityRisk;
        return this;
    }

    /**
     * Get entityRisk
     *
     * @return entityRisk
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENTITY_RISK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EntityRiskPolicyRuleAllOfActionsEntityRisk getEntityRisk() {
        return entityRisk;
    }

    @JsonProperty(JSON_PROPERTY_ENTITY_RISK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEntityRisk(EntityRiskPolicyRuleAllOfActionsEntityRisk entityRisk) {
        this.entityRisk = entityRisk;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EntityRiskPolicyRuleAllOfActions entityRiskPolicyRuleAllOfActions = (EntityRiskPolicyRuleAllOfActions) o;
        return Objects.equals(this.entityRisk, entityRiskPolicyRuleAllOfActions.entityRisk);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(entityRisk);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EntityRiskPolicyRuleAllOfActions {\n");
        sb.append("    entityRisk: ").append(toIndentedString(entityRisk)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
